@@ -12,10 +12,12 @@ if [ -z "${AUTOPKGTEST_TMP+x}" ] || [ -z "${AUTOPKGTEST_ARTIFACTS+x}" ]; then
   exit 1
 fi
 
+ulimit -c unlimited
+
 host_arch="${DEB_HOST_ARCH:-$(dpkg --print-architecture)}"
 
 if [ -z "${JDK_TO_TEST+x}" ]; then
-  JDK_TO_TEST=$(echo /usr/lib/jvm/java-21-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
+  JDK_TO_TEST=$(echo /usr/lib/jvm/java-25-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
 fi
 
 if [ -z "${BOOTJDK_HOME+x}" ]; then
@@ -32,7 +34,7 @@ fi
 if dpkg --compare-versions ${jtreg_version} ge 4.2; then
   jt_options+=" -conc:auto"
 fi
-  
+
 # check java binary
 if [ ! -x "${JDK_TO_TEST}/bin/java" ]; then
   echo "Error: JDK_TO_TEST: '${JDK_TO_TEST}/bin/java' is not an executable." >&2
@@ -45,7 +47,7 @@ if [ ! -x "${BOOTJDK_HOME}/bin/java" ]; then
 fi
 
 # restrict the tests to a few archs (set from debian/rules)
-if ! echo "${host_arch}" | grep -qE "^($(echo amd64 i386 arm64 armhf ppc64 ppc64el riscv64 s390x alpha ia64 powerpc ppc64 sh4 x32 armel mipsel mips64el riscv64 | tr ' ' '|'))$"; then
+if ! echo "${host_arch}" | grep -qE "^($(echo amd64 arm64 ppc64 ppc64el riscv64 s390x alpha ia64 powerpc ppc64 sh4 x32 armel loong64 mipsel mips64el riscv64 | tr ' ' '|'))$"; then
   echo "Error: ${host_arch} is not on the jtreg_archs list, ignoring it."
   exit 77
 fi
@@ -103,12 +105,14 @@ for i in 0 1 2; do
     -retain:none \
     -ignore:quiet \
     -agentvm \
-    -timeout:5 \
+    -timeout:10 \
     -workDir:"${jtwork_dir}" \
     -reportDir:"${report_dir}" \
     -jdk:${JDK_TO_TEST} \
     -vmoption:-Dtest.boot.jdk=${BOOTJDK_HOME} \
     -vmoption:-XX:MaxRAMPercentage=25 \
+    -vmoption:-Duser.home=${AUTOPKGTEST_TMP} \
+    -vmoption:-Djava.io.tmpdir=${AUTOPKGTEST_TMP} \
     -e:NSS_DEFAULT_DB_TYPE=sql \
     ${on_retry:-} $@ \
       && exit_code=0 || exit_code=$?
